Limits

Struct Limits 

pub struct Limits {
    pub input_file_size: usize,
    pub decompressed_json_size: usize,
}
Protects against denial-of-service attacks via infinite input streams or zip bombs, which would otherwise use up all your memory and crash your machine.

If the limit is exceeded, an error is returned and no further deserialization is attempted.

The default limits are 1 GiB for the input_file_size and 8 MiB for decompressed_json_size.

Note that the decompressed_json_size is only enforced on the level of the serialized JSON, i.e. a string. We do not enforce that serde_json does not consume more memory when deserializing JSON to Rust data structures. Unfortunately Rust does not provide APIs for that.

Fields

input_file_size: usizedecompressed_json_size: usize